@@ -20,6 +20,9 @@ AUTHFAILURE = 'AuthFailure'
 # AuthFailure.UnauthorizedOperation
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 
+# DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
+DRYRUNOPERATION = 'DryRunOperation'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
